# djtodo-cli

djtodo-cli is a CLI todo application.

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install djtodo-cli.

```bash
pip install djtodo-cli
```

## Usage

```add
djtodo-cli add <task>
```
>add task

```list
djtodo-cli list
```
>print list of task

```remove
djtodo-cli remove <number>
```
> remove task

```done
djtodo-cli done <number>
```
>mark task as done
 
  
## Contributing

Pull requests are welcome. For major changes, please open an issue first
to discuss what you would like to change.

Please make sure to update tests as appropriate.

## License

[MIT](https://choosealicense.com/licenses/mit/)



